@@ -60,7 +60,7 @@ class KProgress;
  * @version 0.2.3
  */
 class KNutMainWindow : public TDEMainWindow {
-  Q_OBJECT
+  TQ_OBJECT
   
   public:
 
